@@ -174,7 +174,7 @@ async def eth_getTransactionCount(address, block_identifier="best"):
     '''
     ethereum 用来处理 nonce, Meter 不需要
     '''
-    #return encode_number(0)
+    # return encode_number(0)
     random.seed(time.time())
     nonce = random.randint(1, 0xffffffff)
     print("nonce = " + str(nonce))
@@ -206,7 +206,6 @@ async def eth_blockNumber():
 async def eth_estimateGas(transaction):
     formatted_transaction = input_transaction_formatter(transaction)
     result = await meter.estimate_gas(formatted_transaction)
-    print("RESULT:", result)
     return encode_number(result)
 
 
@@ -311,4 +310,8 @@ async def eth_getFilterChanges(filter_id):
 @method
 @async_serialize
 async def eth_getLogs(filter_obj):
+    to_blk = filter_obj.get('toBlock', None)
+    if (to_blk == 'latest'):
+        latest = await meter.get_block('best')
+        filter_obj['toBlock'] = latest['number']
     return await meter.get_logs(filter_obj.get("address", None), input_log_filter_formatter(filter_obj))
